@@ -56,12 +56,14 @@ var origin2 = &resource.Origin{
 }
 
 func doAppend(t *testing.T, w ResMap, r *resource.Resource) {
+	t.Helper()
 	err := w.Append(r)
 	if err != nil {
 		t.Fatalf("append error: %v", err)
 	}
 }
 func doRemove(t *testing.T, w ResMap, id resid.ResId) {
+	t.Helper()
 	err := w.Remove(id)
 	if err != nil {
 		t.Fatalf("remove error: %v", err)
@@ -116,7 +118,7 @@ func TestAppendRemove(t *testing.T) {
 	doAppend(t, w2, makeCm(2))
 	doAppend(t, w2, makeCm(4))
 	doAppend(t, w2, makeCm(6))
-	if !reflect.DeepEqual(w1, w1) {
+	if !reflect.DeepEqual(w1, w2) {
 		w1.Debug("w1")
 		w2.Debug("w2")
 		t.Fatalf("mismatch")
@@ -299,7 +301,7 @@ func TestGetMatchingResourcesByCurrentId(t *testing.T) {
 		t.Fatalf("Expected single map entry but got %v", result)
 	}
 
-	// nolint:goconst
+	//nolint:goconst
 	tests := []struct {
 		name    string
 		matcher IdMatcher
@@ -431,7 +433,6 @@ func TestGetMatchingResourcesByAnyId(t *testing.T) {
 	m := resmaptest_test.NewRmBuilder(t, rf).
 		AddR(r1).AddR(r2).AddR(r3).AddR(r4).AddR(r5).ResMap()
 
-	// nolint:goconst
 	tests := []struct {
 		name    string
 		matcher IdMatcher
@@ -821,8 +822,9 @@ func TestAppendAll(t *testing.T) {
 	}
 }
 
-func makeMap1() ResMap {
-	return rmF.FromResource(rf.FromMapAndOption(
+func makeMap1(t *testing.T) ResMap {
+	t.Helper()
+	r, err := rf.FromMapAndOption(
 		map[string]interface{}{
 			"apiVersion": "apps/v1",
 			"kind":       "ConfigMap",
@@ -835,11 +837,16 @@ func makeMap1() ResMap {
 			},
 		}, &types.GeneratorArgs{
 			Behavior: "create",
-		}))
+		})
+	if err != nil {
+		t.Fatalf("expected new intance with an options but got error: %v", err)
+	}
+	return rmF.FromResource(r)
 }
 
-func makeMap2(b types.GenerationBehavior) ResMap {
-	return rmF.FromResource(rf.FromMapAndOption(
+func makeMap2(t *testing.T, b types.GenerationBehavior) ResMap {
+	t.Helper()
+	r, err := rf.FromMapAndOption(
 		map[string]interface{}{
 			"apiVersion": "apps/v1",
 			"kind":       "ConfigMap",
@@ -853,14 +860,19 @@ func makeMap2(b types.GenerationBehavior) ResMap {
 			},
 		}, &types.GeneratorArgs{
 			Behavior: b.String(),
-		}))
+		})
+	if err != nil {
+		t.Fatalf("expected new intance with an options but got error: %v", err)
+	}
+	return rmF.FromResource(r)
 }
 
 func TestAbsorbAll(t *testing.T) {
 	metadata := map[string]interface{}{
 		"name": "cmap",
 	}
-	expected := rmF.FromResource(rf.FromMapAndOption(
+
+	r, err := rf.FromMapAndOption(
 		map[string]interface{}{
 			"apiVersion": "apps/v1",
 			"kind":       "ConfigMap",
@@ -873,24 +885,26 @@ func TestAbsorbAll(t *testing.T) {
 		},
 		&types.GeneratorArgs{
 			Behavior: "create",
-		}))
-	w := makeMap1()
-	assert.NoError(t, w.AbsorbAll(makeMap2(types.BehaviorMerge)))
+		})
+	if err != nil {
+		t.Fatalf("expected new intance with an options but got error: %v", err)
+	}
+	expected := rmF.FromResource(r)
+	w := makeMap1(t)
+	assert.NoError(t, w.AbsorbAll(makeMap2(t, types.BehaviorMerge)))
 	expected.RemoveBuildAnnotations()
 	w.RemoveBuildAnnotations()
 	assert.NoError(t, expected.ErrorIfNotEqualLists(w))
-	w = makeMap1()
+	w = makeMap1(t)
 	assert.NoError(t, w.AbsorbAll(nil))
-	assert.NoError(t, w.ErrorIfNotEqualLists(makeMap1()))
+	assert.NoError(t, w.ErrorIfNotEqualLists(makeMap1(t)))
 
-	w = makeMap1()
-	w2 := makeMap2(types.BehaviorReplace)
+	w = makeMap1(t)
+	w2 := makeMap2(t, types.BehaviorReplace)
 	assert.NoError(t, w.AbsorbAll(w2))
 	w2.RemoveBuildAnnotations()
 	assert.NoError(t, w2.ErrorIfNotEqualLists(w))
-	w = makeMap1()
-	w2 = makeMap2(types.BehaviorUnspecified)
-	err := w.AbsorbAll(w2)
+	err = makeMap1(t).AbsorbAll(makeMap2(t, types.BehaviorUnspecified))
 	assert.Error(t, err)
 	assert.True(
 		t, strings.Contains(err.Error(), "behavior must be merge or replace"))
