@@ -6,11 +6,17 @@ package set
 import (
 	"github.com/spf13/cobra"
 	"sigs.k8s.io/kustomize/api/ifc"
+	"sigs.k8s.io/kustomize/api/resource"
 	"sigs.k8s.io/kustomize/kyaml/filesys"
 )
 
 // NewCmdSet returns an instance of 'set' subcommand.
-func NewCmdSet(fSys filesys.FileSystem, ldr ifc.KvLoader, v ifc.Validator) *cobra.Command {
+func NewCmdSet(
+	fSys filesys.FileSystem,
+	ldr ifc.KvLoader,
+	v ifc.Validator,
+	rf *resource.Factory,
+) *cobra.Command {
 	c := &cobra.Command{
 		Use:   "set",
 		Short: "Sets the value of different fields in kustomization file",
@@ -26,6 +32,7 @@ func NewCmdSet(fSys filesys.FileSystem, ldr ifc.KvLoader, v ifc.Validator) *cobr
 	}
 
 	c.AddCommand(
+		newCmdSetConfigMap(fSys, ldr, rf),
 		newCmdSetNamePrefix(fSys),
 		newCmdSetNameSuffix(fSys),
 		newCmdSetNamespace(fSys, v),
