@@ -26,7 +26,7 @@ func TestByteReadWriter(t *testing.T) {
 		{
 			name: "round_trip",
 			input: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -38,7 +38,7 @@ items:
       foo: bar
 `,
 			expectedOutput: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -54,7 +54,7 @@ items:
 		{
 			name: "function_config",
 			input: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -68,7 +68,7 @@ functionConfig:
   a: b # something
 `,
 			expectedOutput: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -86,7 +86,7 @@ functionConfig:
 		{
 			name: "results",
 			input: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -100,7 +100,7 @@ results:
   a: b # something
 `,
 			expectedOutput: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -118,7 +118,7 @@ results:
 		{
 			name: "drop_invalid_resource_list_field",
 			input: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -132,7 +132,7 @@ foo:
   a: b # something
 `,
 			expectedOutput: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -233,7 +233,7 @@ metadata:
 		{
 			name: "manual_override_wrap",
 			input: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -262,7 +262,7 @@ spec:
 		{
 			name: "manual_override_function_config",
 			input: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -276,7 +276,7 @@ functionConfig:
   a: b # something
 `,
 			expectedOutput: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 - kind: Deployment
@@ -499,7 +499,7 @@ env:
 		{
 			name: "unwrap ResourceList with annotations",
 			input: `
-apiVersion: config.kubernetes.io/v1alpha1
+apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
   - kind: Deployment
@@ -663,7 +663,7 @@ func TestByteReadWriter_WrapBareSeqNode(t *testing.T) {
 - foo
 - bar
 `,
-			readerErr: "wrong Node Kind for  expected: MappingNode was SequenceNode",
+			readerErr: "wrong node kind: expected MappingNode but got SequenceNode",
 		},
 		{
 			name:            "error round_trip bare seq node",
@@ -686,7 +686,7 @@ func TestByteReadWriter_WrapBareSeqNode(t *testing.T) {
       served: true
       storage: false
 `,
-			readerErr: "wrong Node Kind for  expected: MappingNode was SequenceNode",
+			readerErr: "wrong node kind: expected MappingNode but got SequenceNode",
 		},
 		{
 			name:            "round_trip bare seq node json",
@@ -698,7 +698,7 @@ func TestByteReadWriter_WrapBareSeqNode(t *testing.T) {
 			name:            "error round_trip invalid yaml node",
 			wrapBareSeqNode: false,
 			input:           "I am not valid",
-			readerErr:       "wrong Node Kind for  expected: MappingNode was ScalarNode",
+			readerErr:       "wrong node kind: expected MappingNode but got ScalarNode",
 		},
 	}
 
@@ -747,3 +747,122 @@ func TestByteReadWriter_WrapBareSeqNode(t *testing.T) {
 		})
 	}
 }
+
+func TestByteReadWriter_ResourceListWrapping(t *testing.T) {
+	singleDeployment := `kind: Deployment
+apiVersion: v1
+metadata:
+  name: tester
+  namespace: default
+spec:
+  replicas: 0`
+	resourceList := `apiVersion: config.kubernetes.io/v1
+kind: ResourceList
+items:
+- kind: Deployment
+  apiVersion: v1
+  metadata:
+    name: tester
+    namespace: default
+  spec:
+    replicas: 0`
+	resourceListWithError := `apiVersion: config.kubernetes.io/v1
+kind: ResourceList
+items:
+- kind: Deployment
+  apiVersion: v1
+  metadata:
+    name: tester
+    namespace: default
+  spec:
+    replicas: 0
+results:
+- message: some error
+  severity: error`
+	resourceListDifferentWrapper := strings.NewReplacer(
+		"kind: ResourceList", "kind: SomethingElse",
+		"apiVersion: config.kubernetes.io/v1", "apiVersion: fakeVersion",
+	).Replace(resourceList)
+
+	testCases := []struct {
+		desc           string
+		noWrap         bool
+		wrapKind       string
+		wrapAPIVersion string
+		input          string
+		want           string
+	}{
+		{
+			desc:  "resource list",
+			input: resourceList,
+			want:  resourceList,
+		},
+		{
+			desc:  "individual resources",
+			input: singleDeployment,
+			want:  singleDeployment,
+		},
+		{
+			desc:           "no nested wrapping",
+			wrapKind:       kio.ResourceListKind,
+			wrapAPIVersion: kio.ResourceListAPIVersion,
+			input:          resourceList,
+			want:           resourceList,
+		},
+		{
+			desc:   "unwrap resource list",
+			noWrap: true,
+			input:  resourceList,
+			want:   singleDeployment,
+		},
+		{
+			desc:           "wrap individual resources",
+			wrapKind:       kio.ResourceListKind,
+			wrapAPIVersion: kio.ResourceListAPIVersion,
+			input:          singleDeployment,
+			want:           resourceList,
+		},
+		{
+			desc:           "NoWrap has precedence",
+			noWrap:         true,
+			wrapKind:       kio.ResourceListKind,
+			wrapAPIVersion: kio.ResourceListAPIVersion,
+			input:          singleDeployment,
+			want:           singleDeployment,
+		},
+		{
+			desc:           "honor specified wrapping kind",
+			wrapKind:       "SomethingElse",
+			wrapAPIVersion: "fakeVersion",
+			input:          resourceList,
+			want:           resourceListDifferentWrapper,
+		},
+		{
+			desc:  "passthrough results",
+			input: resourceListWithError,
+			want:  resourceListWithError,
+		},
+	}
+
+	for i := range testCases {
+		tc := testCases[i]
+		t.Run(tc.desc, func(t *testing.T) {
+			var got bytes.Buffer
+			rw := kio.ByteReadWriter{
+				Reader:             strings.NewReader(tc.input),
+				Writer:             &got,
+				NoWrap:             tc.noWrap,
+				WrappingAPIVersion: tc.wrapAPIVersion,
+				WrappingKind:       tc.wrapKind,
+			}
+
+			rnodes, err := rw.Read()
+			assert.NoError(t, err)
+
+			err = rw.Write(rnodes)
+			assert.NoError(t, err)
+
+			assert.Equal(t, tc.want, strings.TrimSpace(got.String()))
+		})
+	}
+}
